/* Exemplet visar hur man på händelsen dragenter kan ge en visuell feedback,
   genom förändring av elementets stil. Stilen tas sedan bort på händelsen
   dragleave. Därmed blir det som en "hover-effekt" i CSS. Man kan dock inte
   använda hover i CSS, eftersom webbläsaren inte känner av denna pseudoklass
   under drag-and-drop. Så därför måste man göra det i JavaScript med dragenter
   och dragleave. Stilen måste även tas bort för händelsen drop, eftersom
   dragleave inte inträffar om drop inträffar. */
// --------------------------------------------------
// Globala variabler och konstanter

// --------------------------------------------------
// Initiering då webbsidan är inläst
function init() {
    let dragElems = document.querySelectorAll("#dragItems div");
    for (let i = 0; i < dragElems.length; i++) {
        dragElems[i].draggable = true;
        dragElems[i].addEventListener("dragstart", dragStart);
    }
} // Slut init
window.addEventListener("load", init);
// --------------------------------------------------
// Hantera en drag-operation
function dragStart(e) {
    let dragElem = this; // Det element som dras
    let dropElems = document.querySelectorAll("#dropZones div"); // Array med "drop zones"
    dragElem.addEventListener("dragend", dragEnd);
    for (let i = 0; i < dropElems.length; i++) {
        dropElems[i].addEventListener("dragover", dropZone);
        dropElems[i].addEventListener("dragenter", dropZone);
        dropElems[i].addEventListener("dragleave", dropZone);
        dropElems[i].addEventListener("drop", dropZone);
    }
    // ----------
    // Avsluta drag-operationen
    function dragEnd(e) {
        dragElem.removeEventListener("dragend", dragEnd);
        for (let i = 0; i < dropElems.length; i++) {
            dropElems[i].removeEventListener("dragover", dropZone);
            dropElems[i].removeEventListener("dragenter", dropZone);
            dropElems[i].removeEventListener("dragleave", dropZone);
            dropElems[i].removeEventListener("drop", dropZone);
        }
    } // Slut dragEnd
    // ----------
    // Hantera händelser för drop zones
    function dropZone(e) {
        e.preventDefault();
        let dropElem = this; // Det element som man drar över eller släppt på, (funkar även med e.currentTarget)
        switch (e.type) {
            case "dragenter": // Visuell feedback
                dropElem.style.backgroundColor = "#6C9";
                //dropElem.classList.add("hiliteDropZone");
                break;
            case "dragleave": // Ta bort visuell feedback
                dropElem.style.backgroundColor = "";
                //dropElem.classList.remove("hiliteDropZone");
                break;
            case "drop":  // Gör vad som ska ske då man släpper på en drop zone
                dropElem.style.backgroundColor = ""; // Ta bort visuell feedback
                //dropElem.classList.remove("hiliteDropZone");
        } // Slut switch
    } // Slut dropZone
    // ----------
} // Slut dragStart
// --------------------------------------------------
