/* Exemplet visar olika sätt att välja vilka drop zones som det är tillåtet att
   släppa på. Ett alternativ är att ha en if-sats i början av funktionen dropZone,
   för att avgöra om man ska kunna släppa på den. Om det inte är tillåtet, lämnar
   man funktionen med return och resten av hanteringen av händelserna utförs då inte.
   Ett annat alternativ är att i drgStart välja ut vilka element som det är tillåtet
   att släppa på. Sedan läggs händelsehanterarna för dragover, etc. endast på dessa.
   I detta exempel sker urvalet med hjälp av en klass. */
// --------------------------------------------------
// Globala variabler och konstanter

// --------------------------------------------------
// Initiering då webbsidan är inläst
function init() {
    let dragElems = document.querySelectorAll("#dragItems div");
    for (let i = 0; i < dragElems.length; i++) {
        dragElems[i].draggable = true;
        dragElems[i].addEventListener("dragstart", dragStart);
    }
    let dropElems = document.querySelectorAll("#dropZones div");
    for (let i = 0; i < dropElems.length; i++) {
        dropElems[i].addEventListener("click", markBox);
    }
} // Slut init
window.addEventListener("load", init);
// --------------------------------------------------
// Markera / avmarkera den drop zone, som användaren klickat på
function markBox() {
    this.classList.toggle("marked");
} // Slut markBox
// --------------------------------------------------
// Hantera en drag-operation
function dragStart(e) {
    let dragElem = this; // Det element som dras
    //let dropElems = document.querySelectorAll("#dropZones div"); // Array med "drop zones"
    let dropElems = document.querySelectorAll("#dropZones div:not(.marked)");
    dragElem.addEventListener("dragend", dragEnd);
    for (let i = 0; i < dropElems.length; i++) {
        dropElems[i].addEventListener("dragover", dropZone);
        dropElems[i].addEventListener("dragenter", dropZone);
        dropElems[i].addEventListener("dragleave", dropZone);
        dropElems[i].addEventListener("drop", dropZone);
    }
    // ----------
    // Avsluta drag-operationen
    function dragEnd(e) {
        dragElem.removeEventListener("dragend", dragEnd);
        for (let i = 0; i < dropElems.length; i++) {
            dropElems[i].removeEventListener("dragover", dropZone);
            dropElems[i].removeEventListener("dragenter", dropZone);
            dropElems[i].removeEventListener("dragleave", dropZone);
            dropElems[i].removeEventListener("drop", dropZone);
        }
    } // Slut dragEnd
    // ----------
    // Hantera händelser för drop zones
    function dropZone(e) {
        e.preventDefault();
        let dropElem = this; // Det element som man drar över eller släppt på
        //if (dropElem.innerHTML == "A") return; // Lämna funktionen
        //if (dropElem.innerHTML != "") return;
        //if (dropElem.classList.contains("marked")) return;
        switch (e.type) {
            case "dragenter":
                dropElem.classList.add("hiliteDropZone");
                break;
            case "dragleave":
                dropElem.classList.remove("hiliteDropZone");
                break;
            case "drop":
                dropElem.classList.remove("hiliteDropZone");
                dropElem.innerHTML = dragElem.innerHTML;
                dragElem.classList.add("taken");
                dragElem.draggable = false;
        } // Slut switch
    } // Slut dropZone
    // ----------
} // Slut dragStart
// --------------------------------------------------
